# Import console logging / printing functions
from fruit.modules.console import echo, error, warning

# Export decorators
from fruit.api.decorators import target, step

# Export exceptions
from fruit.api.api import abort

# Export the shell module
from fruit.api.shell import shell
